@@ -562,8 +562,8 @@ def hierarchicalUpdate(curDict: dict, other: dict, replaceLists=False):
   for k, v in other.items():
     curVal = curDict.get(k, None)
     if isinstance(curVal, dict) and isinstance(v, dict):
-      hierarchicalUpdate(curVal, v)
-    elif replaceLists and isinstance(curVal, list) and isinstance(v, list):
+      hierarchicalUpdate(curVal, v, replaceLists)
+    elif not replaceLists and isinstance(curVal, list) and isinstance(v, list):
       curVal.extend(v)
     else:
       curDict[k] = v
