@@ -161,9 +161,10 @@ class PopupLineEditor(QtWidgets.QLineEdit):
     self.setPlaceholderText(placeholderText)
     self.clearOnComplete = clearOnComplete
     self.forceMatch = forceMatch
-
-    if model is not None:
-      self.setModel(model)
+    self.model: QtCore.QAbstractListModel = QtCore.QStringListModel()
+    if model is None:
+      model = self.model
+    self.setModel(model)
 
   def setModel(self, model: QtCore.QAbstractListModel):
     completer = QtWidgets.QCompleter(model, self)
@@ -176,6 +177,7 @@ class PopupLineEditor(QtWidgets.QLineEdit):
     self.textChanged.connect(lambda: self.resetCompleterPrefix())
 
     self.setCompleter(completer)
+    self.model = model
 
   # TODO: Get working with next prev focusing for smoother logic
   # def focusNextPrevChild(self, nextChild: bool):
@@ -379,7 +381,7 @@ class ButtonCollection(QtWidgets.QGroupBox):
 
 _layoutTypes = t.Union[Literal['H'], Literal['V']]
 class EasyWidget:
-  def __init__(self, children: t.Sequence[t.Union[QtWidgets.QWidget, EasyWidget]],
+  def __init__(self, children: t.List[t.Union[QtWidgets.QWidget, EasyWidget]],
                layout: str=None, useSplitter=False, baseWidget: QtWidgets.QWidget=None):
     if baseWidget is None:
       baseWidget = QtWidgets.QWidget()
@@ -418,7 +420,9 @@ class EasyWidget:
       chSuggested = None
 
     for ii, child in enumerate(self.children_):
-      self.addChild(child, chSuggested)
+      morphChild = self.addChild(child, chSuggested)
+      if morphChild is not child:
+        self.children_[ii] = morphChild
 
   def addChild(self, child: t.Union[QtWidgets.QWidget, t.Sequence, EasyWidget], suggestedLayout:str=None):
     if isinstance(child, QtWidgets.QWidget):
@@ -428,6 +432,7 @@ class EasyWidget:
       # At this point, child should be an EasyWidget
       child.build()
       self.layout_.addWidget(child.widget_)
+    return child
 
   @classmethod
   def listChildrenWrapper(cls, children: t.Union[t.Sequence, EasyWidget], maybeNewLayout: str=None):
